@@ -241,10 +241,7 @@ if TYPE_CHECKING:
                 "boolean",
                 "double",
                 "integer",
-                "string[]",
-                "boolean[]",
-                "double[]",
-                "integer[]",
+                "array",
             ],
             "value": AttributeValue,
         },
